@@ -1,5 +1,5 @@
 /* AbiSource Program Utilities
- * Copyright (C) 2004 Hubert Figuiere
+ * Copyright (C) 2004-2025 Hubert Figuière
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,6 +28,8 @@ class ABI_EXPORT UT_PropVector
 public:
 	UT_PropVector()
 		: UT_GenericVector<gchar*>() {};
+	virtual ~UT_PropVector();
+	void clear();
 	void addOrReplaceProp(const gchar * pszProp, const gchar * pszVal);
 	void getProp(const gchar * pszProp, const gchar * &pszVal) const;
 	void removeProp(const gchar * pszProp);
