@@ -1,8 +1,8 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-/* 
+/*
  * xap_TableWidget.cpp
  * Copyright 2002 Joaquin Cuenca Abela
- * Copyright 2016 Hubert Figuiere
+ * Copyright 2016-2024 Hubert Figuière
  *
  * Authors:
  *   Joaquin Cuenca Abela (e98cuenc@yahoo.com)
@@ -100,7 +100,7 @@ cells_to_pixels(guint cols, guint rows, guint* w, guint* h)
 {
 	UT_return_if_fail(w);
 	UT_return_if_fail(h);
-	
+
 	*w = cell_width * cols + cell_spacing * (cols + 1);
 	*h = cell_height * rows + cell_spacing * (rows + 1);
 }
@@ -110,7 +110,7 @@ pixels_to_cells(guint w, guint h, guint* cols, guint* rows)
 {
 	UT_return_if_fail(cols);
 	UT_return_if_fail(rows);
-	
+
 	*cols = w / (cell_width + cell_spacing) + 1;
 	*rows = h / (cell_height + cell_spacing) + 1;
 }
@@ -317,11 +317,20 @@ on_motion_notify_event (GtkWidget *window, GdkEventMotion *ev, gpointer user_dat
 	AbiTable* table = static_cast<AbiTable*>(user_data);
 	guint selected_cols;
 	guint selected_rows;
+	double x = ev->x;
+	double y = ev->y;
 
-	if (ev->x < 0 || ev->y < 0)
+
+#if GTK_CHECK_VERSION(3, 0, 0)
+	// In Gtk3, the coordinate of the motion event are relative to the top-level
+	x -= table->pos_x;
+	y -= table->pos_y;
+#endif
+
+	if (x < 0 || y < 0)
 		return TRUE;
-	
-	pixels_to_cells(static_cast<guint>(ev->x), static_cast<guint>(ev->y), &selected_cols, &selected_rows);
+
+	pixels_to_cells(static_cast<guint>(x), static_cast<guint>(y), &selected_cols, &selected_rows);
 
 	if ((selected_cols != table->selected_cols) || (selected_rows != table->selected_rows))
 	{
@@ -420,6 +429,7 @@ static gboolean
 popup_grab_on_window (GdkWindow *window,
 					  guint32    activate_time)
 {
+#if !GTK_CHECK_VERSION(3,20,0)
 	GdkEventMask emask = static_cast<GdkEventMask>(GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
 												   GDK_POINTER_MOTION_MASK | GDK_LEAVE_NOTIFY_MASK |
 												   GDK_ENTER_NOTIFY_MASK) ;
@@ -437,6 +447,11 @@ popup_grab_on_window (GdkWindow *window,
 	}
 
 	return FALSE;
+#else
+	GdkSeat *seat = gdk_display_get_default_seat(gdk_window_get_display(window));
+    return gdk_seat_grab(seat, window, GDK_SEAT_CAPABILITY_ALL,
+                         FALSE, nullptr, nullptr, nullptr, nullptr) == GDK_GRAB_SUCCESS;
+#endif
 }
 
 static void
@@ -459,8 +474,9 @@ on_pressed(GtkButton* button, gpointer user_data)
 	gtk_window_set_transient_for(table->window, GTK_WINDOW(toplevel));
 	gdk_window_get_origin (gtk_widget_get_window(GTK_WIDGET(table)), &left, &top);
 	gtk_widget_get_allocation(GTK_WIDGET(table), &alloc);
-	gtk_window_move(table->window,
-	                left + alloc.x,	top + alloc.y + alloc.height);
+	table->pos_x = left + alloc.x;
+	table->pos_y = top + alloc.y + alloc.height;
+	gtk_window_move(table->window, table->pos_x, table->pos_y);
 	abi_table_resize(table);
 
 	gtk_widget_show(GTK_WIDGET(table->window));
@@ -533,116 +549,6 @@ on_key_event(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 	return TRUE;
 }
 
-
-/* XPM */
-static const char * widget_tb_insert_table_xpm[] = {
-	"24 24 32 1",
-	" 	c None",
-	".	c #000000",
-	"+	c #FFFFFF",
-	"@	c #B1B1B1",
-	"#	c #BABABA",
-	"$	c #E4E4E4",
-	"%	c #ECECEC",
-	"&	c #A8A8A8",
-	"*	c #ADADAD",
-	"=	c #B9B9B9",
-	"-	c #ABABAB",
-	";	c #B8B8B8",
-	">	c #B5B5B5",
-	",	c #AAAAAA",
-	"'	c #858585",
-	")	c #828282",
-	"!	c #707070",
-	"~	c #BCBCBC",
-	"{	c #A7A7A7",
-	"]	c #8D8D8D",
-	"^	c #737373",
-	"/	c #ACACAC",
-	"(	c #878787",
-	"_	c #747474",
-	":	c #A9A9A9",
-	"<	c #E9E9E9",
-	"[	c #C3C3C3",
-	"}	c #BFBFBF",
-	"|	c #757575",
-	"1	c #7E7E7E",
-	"2	c #BBBBBB",
-	"3	c #A3A3A3",
-	"                        ",
-	"                        ",
-	"                        ",
-	"   ...................  ",
-	"   .+++++@+++++#++++$.  ",
-	"   .+%%%%&%%%%%*%%%%=.  ",
-	"   .+%%%%-%%%%%-%%%%;.  ",
-	"   .>&,,&'&----)&---!.  ",
-	"   .+%%%%-%%%%%-%%%%~.  ",
-	"   .+%%%%-%%%%%-%%%%~.  ",
-	"   .+%%%%-%%%%%-%%%%~.  ",
-	"   .#{---'-----]*---^.  ",
-	"   .+%%%%-%%%%%-%%%%~.  ",
-	"   .+%%%%-%%%%%-%%%%;.  ",
-	"   .+%%%%-%%%%%-%%%%~.  ",
-	"   .;&--/(&{--&'&---_.  ",
-	"   .+%%%%-%%%%%-%%%%;.  ",
-	"   .+%%%%&%%%%%:%%%%~.  ",
-	"   .<[[[}|~~~~~1;~~23.  ",
-	"   ...................  ",
-	"                        ",
-	"                        ",
-	"                        ",
-	"                        "};
-
-
-static void
-register_stock_icon(void)
-{
-	static gboolean registered = FALSE;
-  
-	if (!registered)
-	{
-		GdkPixbuf *pixbuf;
-		GtkIconFactory *factory;
-
-		static GtkStockItem items[] = {
-			{ (gchar*)"abi-table-widget",
-			  (gchar*)"_Table",
-			  static_cast<GdkModifierType>(0), 0, NULL }
-		};
-      
-		registered = TRUE;
-
-		/* Register our stock items */
-		gtk_stock_add (items, G_N_ELEMENTS (items));
-      
-		/* Add our custom icon factory to the list of defaults */
-		factory = gtk_icon_factory_new ();
-		gtk_icon_factory_add_default (factory);
-
-		// Must be C cast
-		pixbuf = gdk_pixbuf_new_from_xpm_data((const char **)widget_tb_insert_table_xpm);
-
-		/* Register icon to accompany stock item */
-		if (pixbuf != NULL)
-		{
-			GtkIconSet *icon_set;
-          
-			icon_set = gtk_icon_set_new_from_pixbuf (pixbuf);
-			gtk_icon_factory_add (factory, "abi-table-widget", icon_set);
-			gtk_icon_set_unref (icon_set);
-			g_object_unref (G_OBJECT (pixbuf));
-		}
-		else
-		{
-			UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
-		}
-				
-		/* Drop our reference to the factory, GTK will hold a reference. */
-		g_object_unref (G_OBJECT (factory));
-	}
-}
-
 void abi_table_set_icon(AbiTable* abi_table,GtkWidget * gtkImageIcon)
 {
 	if(!GTK_IS_IMAGE(G_OBJECT(gtkImageIcon)))
@@ -703,8 +609,6 @@ abi_table_init (AbiTable* table)
 {
 	char* text = g_strdup_printf("%d x %d ", init_rows, init_cols);
 
-	register_stock_icon();
-
 #if GTK_CHECK_VERSION(3,0,0)
 	table->style_context = XAP_GtkStyle_get_style(NULL, "GtkTreeView.view"); // "textview.view"
 #endif
@@ -727,6 +631,8 @@ abi_table_init (AbiTable* table)
 
 	gtk_widget_show_all(GTK_WIDGET(table->window_vbox));
 
+	table->pos_x = 0;
+	table->pos_y = 0;
 	table->selected_rows = init_rows;
 	table->selected_cols = init_cols;
 
@@ -735,29 +641,16 @@ abi_table_init (AbiTable* table)
 
 	abi_table_resize(table);
 
-	table->icon = NULL;
-	if (gtk_stock_lookup ("abi-table-widget", &table->stock_item))
-	{
-		table->label = gtk_label_new_with_mnemonic(table->stock_item.label);
-		table->icon = gtk_image_new_from_stock ("abi-table-widget", GTK_ICON_SIZE_LARGE_TOOLBAR);
-		gtk_widget_show(table->icon);
-		gtk_widget_show(table->label);
-		g_object_ref_sink(table->label);
-		//
-		// We actually never want this label in toolbar
-		//		gtk_box_pack_end(GTK_BOX(table->button_box), table->label, FALSE, FALSE, 0);
-		gtk_box_pack_end(GTK_BOX(table->button_box), table->icon, FALSE, FALSE, 0);
-		UT_DEBUGMSG(("abi-table icon loaded %p !\n",table->icon));
-	}
-	else
-	{
-		/* it should not happen... */
-		UT_DEBUGMSG(("abi-table icon did not load !\n"));
-		UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
-		table->label = gtk_label_new_with_mnemonic("_Table");
-		g_object_ref_sink(table->label);
-		//		gtk_box_pack_end(GTK_BOX(table->button_box), table->label, FALSE, FALSE, 0);
-	}
+	table->label = gtk_label_new_with_mnemonic(table->stock_item.label);
+	table->icon = gtk_image_new_from_resource("/com/abisource/AbiWord/24x24/actions/tb_insert_table.png");
+	gtk_widget_show(table->icon);
+	gtk_widget_show(table->label);
+	g_object_ref_sink(table->label);
+	//
+	// We actually never want this label in toolbar
+	//		gtk_box_pack_end(GTK_BOX(table->button_box), table->label, FALSE, FALSE, 0);
+	gtk_box_pack_end(GTK_BOX(table->button_box), table->icon, FALSE, FALSE, 0);
+	UT_DEBUGMSG(("abi-table icon loaded %p !\n",table->icon));
 
 	gtk_container_add(GTK_CONTAINER(table), GTK_WIDGET(table->button_box));
 
