@@ -1,7 +1,8 @@
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
  * Copyright (C) 2003 Marc Maurer
- * Copyright (C) 2009, 2013 Hubert Figuiere
+ * Copyright (C) 2009-2024 Hubert Figuière
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -442,10 +443,10 @@ GtkWidget * AP_UnixDialog_FormatFrame::_constructWindow(void)
 	m_wLineRight = GTK_WIDGET(gtk_builder_get_object(builder, "tbBorderRight"));
 	m_wLineBottom = GTK_WIDGET(gtk_builder_get_object(builder, "tbBorderBottom"));
 	// place some nice pixmaps on our border toggle buttons
-	label_button_with_abi_pixmap(m_wLineTop, "tb_LineTop_xpm");
-	label_button_with_abi_pixmap(m_wLineLeft, "tb_LineLeft_xpm");
-	label_button_with_abi_pixmap(m_wLineRight, "tb_LineRight_xpm");
-	label_button_with_abi_pixmap(m_wLineBottom, "tb_LineBottom_xpm");
+	label_button_with_abi_pixmap(m_wLineTop, "tb_LineTop_xpm", 24);
+	label_button_with_abi_pixmap(m_wLineLeft, "tb_LineLeft_xpm", 24);
+	label_button_with_abi_pixmap(m_wLineRight, "tb_LineRight_xpm", 24);
+	label_button_with_abi_pixmap(m_wLineBottom, "tb_LineBottom_xpm", 24);
 	
 	// set button states
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_wLineTop), getTopToggled());  
