@@ -1,5 +1,6 @@
 /* AbiWord
  * Copyright (C) 1998 AbiSource, Inc.
+ * Copyright (C) 2025 Hubert Figuière
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -64,17 +65,9 @@ AP_Dialog_Styles::~AP_Dialog_Styles(void)
 	DELETEP(m_pParaPreview);
 	DELETEP(m_pCharPreview);
 	DELETEP(m_pAbiPreview);
-	for(i=0; i<m_vecAllProps.getItemCount(); i++)
-	{
-		char * psz = (char *) m_vecAllProps.getNthItem(i);
-		FREEP(psz);
-	}
+	UT_VECTOR_FREEALL(gchar*, m_vecAllProps);
 	m_vecAllProps.clear();
-	for(i=0; i<m_vecAllAttribs.getItemCount(); i++)
-	{
-		char * psz = (char *) m_vecAllAttribs.getNthItem(i);
-		FREEP(psz);
-	}
+	UT_VECTOR_FREEALL(gchar*, m_vecAllAttribs);
 	m_vecAllAttribs.clear();
 }
 
@@ -225,6 +218,7 @@ void AP_Dialog_Styles::fillVecFromCurrentPoint(void)
 //
 // Loop over all properties and add them to our vector
 //
+	UT_VECTOR_FREEALL(gchar*, m_vecAllProps);
 	m_vecAllProps.clear();
 	const gchar * szName = NULL;
 	const gchar * szValue = NULL;
@@ -256,9 +250,12 @@ void AP_Dialog_Styles::fillVecFromCurrentPoint(void)
 void AP_Dialog_Styles::fillVecWithProps(const gchar * szStyle, bool bReplaceAttributes = true)
 {
 	PD_Style * pStyle = NULL;
+	UT_VECTOR_FREEALL(gchar*, m_vecAllProps);
 	m_vecAllProps.clear();
-	if( bReplaceAttributes)
+	if( bReplaceAttributes) {
+		UT_VECTOR_FREEALL(gchar *, m_vecAllAttribs);
 		m_vecAllAttribs.clear();
+	}
 	if(szStyle == NULL || ! getDoc()->getStyle(szStyle,&pStyle))
 	{
 		return;
@@ -1718,6 +1715,7 @@ void AP_Dialog_Styles::_populatePreviews(bool isModify)
 									 (const gchar *)paraValues[2], (const gchar *)paraValues[3],
 									 (const gchar *)paraValues[4], (const gchar *)paraValues[5],
 									 (const gchar *)paraValues[6]);
+			FREEP(props_in);
 			if(!isModify)
 				event_charPreviewUpdated();
 		}
