@@ -2005,26 +2005,12 @@ bool IE_Imp_XHTML::pushInline (const char * props)
 
 	const gchar * api_atts[3];
 
-	gchar * sz = NULL;
-
-	sz = g_strdup(PT_PROPS_ATTRIBUTE_NAME);
-	if (sz == NULL)
-		{
-			UT_return_val_if_fail(0,false);
-		}
-	api_atts[0] = sz;
-
-	sz = NULL;
-
-	sz = g_strdup(props);
-	if (sz == NULL)
-		{
-			UT_return_val_if_fail(0,false);
-		}
-	api_atts[1] = sz;
-
+	api_atts[0] = PT_PROPS_ATTRIBUTE_NAME;
+	UT_return_val_if_fail(props, false);
+	api_atts[1] = props;
 	api_atts[2] = NULL;
 
+	// The api_atts strings are strdup
 	_pushInlineFmt (api_atts);
 	return appendFmt (&m_vecInlineFmt);
 }
@@ -2066,43 +2052,15 @@ bool IE_Imp_XHTML::newBlock (const char * style_name, const char * css_style, co
 	api_atts[2] = NULL;
 	api_atts[4] = NULL;
 
-	gchar * sz = NULL;
+	api_atts[0] = PT_STYLE_ATTRIBUTE_NAME;
 
-	sz = g_strdup(PT_STYLE_ATTRIBUTE_NAME);
-	if (sz == NULL)
-		{
-			UT_return_val_if_fail(0,false);
-		}
-	api_atts[0] = sz;
-
-	sz = NULL;
-
-	sz = g_strdup(style_name);
-	if (sz == NULL)
-		{
-			UT_return_val_if_fail(0,false);
-		}
-	api_atts[1] = sz;
+	UT_return_val_if_fail(style_name, false);
+	api_atts[1] = style_name;
 
 	if (utf8val.byteLength ())
 		{
-			sz = NULL;
-
-			sz = g_strdup(PT_PROPS_ATTRIBUTE_NAME);
-			if (sz == NULL)
-				{
-					UT_return_val_if_fail(0,false);
-				}
-			api_atts[2] = sz;
-
-			sz = NULL;
-
-			sz = g_strdup(utf8val.utf8_str ());
-			if (sz == NULL)
-				{
-					UT_return_val_if_fail(0,false);
-				}
-			api_atts[3] = sz;
+			api_atts[2] = PT_PROPS_ATTRIBUTE_NAME;
+			api_atts[3] = utf8val.utf8_str ();
 		}
 	if (!appendStrux (PTX_Block, api_atts))
 		{
@@ -2211,6 +2169,8 @@ bool IE_Imp_XHTML::appendFmt(const UT_GenericVector<const gchar*>* pVecAttribute
 					// FIXME: this is butt ugly !!!!
 					const_cast<UT_GenericVector<const gchar*>*>(pVecAttributes)->deleteNthItem(0);
 					const_cast<UT_GenericVector<const gchar*>*>(pVecAttributes)->deleteNthItem(0);
+					g_free(const_cast<void *>(static_cast<const void *>(pszProp)));
+					g_free(const_cast<void *>(static_cast<const void *>(pszVal)));
 				}
 				if(pVecAttributes->getItemCount() == 0)
 				{
